==========================================
:mod:`numina.frame` --- Frame manipulation
==========================================

.. automodule:: numina.frame
   :synopsis: Frame manipulation
   :members:


.. automodule:: numina.frame.schema
   :synopsis: Schema for FITS header
   :members:
